@@ -1,43 +1,43 @@
 var namespacecl =
 [
+    [ "ImageFormat", "structcl_1_1_image_format.html", "structcl_1_1_image_format" ],
+    [ "Device", "classcl_1_1_device.html", "classcl_1_1_device" ],
+    [ "Platform", "classcl_1_1_platform.html", "classcl_1_1_platform" ],
+    [ "Context", "classcl_1_1_context.html", "classcl_1_1_context" ],
+    [ "Event", "classcl_1_1_event.html", "classcl_1_1_event" ],
+    [ "UserEvent", "classcl_1_1_user_event.html", "classcl_1_1_user_event" ],
+    [ "Memory", "classcl_1_1_memory.html", "classcl_1_1_memory" ],
+    [ "SVMTraitReadWrite", "classcl_1_1_s_v_m_trait_read_write.html", null ],
+    [ "SVMTraitReadOnly", "classcl_1_1_s_v_m_trait_read_only.html", null ],
+    [ "SVMTraitWriteOnly", "classcl_1_1_s_v_m_trait_write_only.html", null ],
+    [ "SVMTraitCoarse", "classcl_1_1_s_v_m_trait_coarse.html", null ],
+    [ "SVMTraitFine", "classcl_1_1_s_v_m_trait_fine.html", null ],
+    [ "SVMTraitAtomic", "classcl_1_1_s_v_m_trait_atomic.html", null ],
+    [ "SVMAllocator", "classcl_1_1_s_v_m_allocator.html", "classcl_1_1_s_v_m_allocator" ],
+    [ "SVMAllocator&lt; void, SVMTrait &gt;", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4.html", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4" ],
     [ "Buffer", "classcl_1_1_buffer.html", "classcl_1_1_buffer" ],
     [ "BufferGL", "classcl_1_1_buffer_g_l.html", "classcl_1_1_buffer_g_l" ],
     [ "BufferRenderGL", "classcl_1_1_buffer_render_g_l.html", "classcl_1_1_buffer_render_g_l" ],
-    [ "CommandQueue", "classcl_1_1_command_queue.html", "classcl_1_1_command_queue" ],
-    [ "Context", "classcl_1_1_context.html", "classcl_1_1_context" ],
-    [ "Device", "classcl_1_1_device.html", "classcl_1_1_device" ],
-    [ "DeviceCommandQueue", "classcl_1_1_device_command_queue.html", "classcl_1_1_device_command_queue" ],
-    [ "EnqueueArgs", "classcl_1_1_enqueue_args.html", null ],
-    [ "Event", "classcl_1_1_event.html", "classcl_1_1_event" ],
     [ "Image", "classcl_1_1_image.html", "classcl_1_1_image" ],
     [ "Image1D", "classcl_1_1_image1_d.html", "classcl_1_1_image1_d" ],
-    [ "Image1DArray", "classcl_1_1_image1_d_array.html", "classcl_1_1_image1_d_array" ],
     [ "Image1DBuffer", "classcl_1_1_image1_d_buffer.html", "classcl_1_1_image1_d_buffer" ],
+    [ "Image1DArray", "classcl_1_1_image1_d_array.html", "classcl_1_1_image1_d_array" ],
     [ "Image2D", "classcl_1_1_image2_d.html", "classcl_1_1_image2_d" ],
-    [ "Image2DArray", "classcl_1_1_image2_d_array.html", "classcl_1_1_image2_d_array" ],
     [ "Image2DGL", "classcl_1_1_image2_d_g_l.html", "classcl_1_1_image2_d_g_l" ],
+    [ "Image2DArray", "classcl_1_1_image2_d_array.html", "classcl_1_1_image2_d_array" ],
     [ "Image3D", "classcl_1_1_image3_d.html", "classcl_1_1_image3_d" ],
     [ "Image3DGL", "classcl_1_1_image3_d_g_l.html", "classcl_1_1_image3_d_g_l" ],
-    [ "ImageFormat", "structcl_1_1_image_format.html", "structcl_1_1_image_format" ],
     [ "ImageGL", "classcl_1_1_image_g_l.html", "classcl_1_1_image_g_l" ],
-    [ "Kernel", "classcl_1_1_kernel.html", "classcl_1_1_kernel" ],
-    [ "KernelFunctor", "classcl_1_1_kernel_functor.html", "classcl_1_1_kernel_functor" ],
-    [ "LocalSpaceArg", "structcl_1_1_local_space_arg.html", null ],
-    [ "Memory", "classcl_1_1_memory.html", "classcl_1_1_memory" ],
-    [ "NDRange", "classcl_1_1_n_d_range.html", "classcl_1_1_n_d_range" ],
     [ "Pipe", "classcl_1_1_pipe.html", "classcl_1_1_pipe" ],
-    [ "Platform", "classcl_1_1_platform.html", "classcl_1_1_platform" ],
-    [ "Program", "classcl_1_1_program.html", "classcl_1_1_program" ],
     [ "Sampler", "classcl_1_1_sampler.html", "classcl_1_1_sampler" ],
-    [ "SVMAllocator", "classcl_1_1_s_v_m_allocator.html", "classcl_1_1_s_v_m_allocator" ],
-    [ "SVMAllocator< void, SVMTrait >", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4.html", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4" ],
-    [ "SVMTraitAtomic", "classcl_1_1_s_v_m_trait_atomic.html", null ],
-    [ "SVMTraitCoarse", "classcl_1_1_s_v_m_trait_coarse.html", null ],
-    [ "SVMTraitFine", "classcl_1_1_s_v_m_trait_fine.html", null ],
-    [ "SVMTraitReadOnly", "classcl_1_1_s_v_m_trait_read_only.html", null ],
-    [ "SVMTraitReadWrite", "classcl_1_1_s_v_m_trait_read_write.html", null ],
-    [ "SVMTraitWriteOnly", "classcl_1_1_s_v_m_trait_write_only.html", null ],
-    [ "UserEvent", "classcl_1_1_user_event.html", "classcl_1_1_user_event" ],
+    [ "NDRange", "classcl_1_1_n_d_range.html", "classcl_1_1_n_d_range" ],
+    [ "LocalSpaceArg", "structcl_1_1_local_space_arg.html", null ],
+    [ "Kernel", "classcl_1_1_kernel.html", "classcl_1_1_kernel" ],
+    [ "Program", "classcl_1_1_program.html", "classcl_1_1_program" ],
+    [ "CommandQueue", "classcl_1_1_command_queue.html", "classcl_1_1_command_queue" ],
+    [ "DeviceCommandQueue", "classcl_1_1_device_command_queue.html", "classcl_1_1_device_command_queue" ],
+    [ "EnqueueArgs", "classcl_1_1_enqueue_args.html", null ],
+    [ "KernelFunctor", "classcl_1_1_kernel_functor.html", "classcl_1_1_kernel_functor" ],
     [ "atomic_svm_vector", "namespacecl.html#a445d7d2f4c3234dc5fbd2d254eb39e22", null ],
     [ "coarse_svm_vector", "namespacecl.html#a2903d8ce897eef7efca4ab6f32f2a197", null ],
     [ "fine_svm_vector", "namespacecl.html#a43fd451f30944f957126b167b4eb0664", null ],
