@@ -2,6 +2,6 @@ var searchData=
 [
   ['makedefault_0',['makeDefault',['../classcl_1_1_device_command_queue.html#acf98d7e70d84afc31789a6f26a95d14b',1,'cl::DeviceCommandQueue::makeDefault(cl_int *err=nullptr)'],['../classcl_1_1_device_command_queue.html#a2188fe106a515329fd90ac58ee95e10e',1,'cl::DeviceCommandQueue::makeDefault(const Context &amp;context, const Device &amp;device, cl_int *err=nullptr)'],['../classcl_1_1_device_command_queue.html#a74abbdd1ba59525634baa4334ae70215',1,'cl::DeviceCommandQueue::makeDefault(const Context &amp;context, const Device &amp;device, cl_uint queueSize, cl_int *err=nullptr)']]],
   ['mapsvm_1',['mapSVM',['../namespacecl.html#ae97dc5bb86e2c3c3935280a86cda301c',1,'cl']]],
-  ['max_5fsize_2',['max_size',['../classcl_1_1_s_v_m_allocator.html#af325042872ad0afb649661b7776024be',1,'cl::SVMAllocator::max_size()'],['../classcl_1_1_s_v_m_allocator.html#af325042872ad0afb649661b7776024be',1,'cl::SVMAllocator&lt; void, SVMTrait &gt;::max_size()'],['../classcl_1_1_s_v_m_allocator.html#af325042872ad0afb649661b7776024be',1,'cl::SVMAllocator&lt; void, SVMTrait &gt;::rebind::max_size()']]],
+  ['max_5fsize_2',['max_size',['../classcl_1_1_s_v_m_allocator.html#af325042872ad0afb649661b7776024be',1,'cl::SVMAllocator::max_size()'],['../classcl_1_1_s_v_m_allocator.html#af325042872ad0afb649661b7776024be',1,'cl::SVMAllocator&lt; void, SVMTrait &gt;::max_size()']]],
   ['memory_3',['Memory',['../classcl_1_1_memory.html#a9926612772ae6e016f1118ef4148da22',1,'cl::Memory::Memory()'],['../classcl_1_1_memory.html#a6fa9f585a65beebcb75e41cca70ee1bb',1,'cl::Memory::Memory(const cl_mem &amp;memory, bool retainObject)']]]
 ];
